from distutils.core import setup

setup(

	name         =   'nester_fbmm',
	version      =   '1.1.0',	 
	py_modules   =   ['nester'],
	author	     =   'bmorapython',
	author_email =   'fbmora88@gmail.com',
	url          =   'http://www.headfirstlabs.com',
        description  =	 'A simple printer of nested lists',
)
